@@ -9,6 +9,13 @@ from .email import Email
 from .file import File
 from .user import User
 from .actionflow import Actionflow
+from .query import Query
+from .worker import Worker
+
 
 settings
-settings.token = ""
\ No newline at end of file
+settings.token = ""
+__version__ = "1.10.0"
+__author__ = "Clappform"
+__email__ = "info@clappform.com"
+__license__ = "MIT"
